@@ -6,9 +6,12 @@ use Carp qw/confess/;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000057';
+our $VERSION = '0.000059';
 
-use Test2::Util::HashBase qw/input negate/;
+use Test2::Util::HashBase qw/input/;
+
+# Overloads '!' for us.
+use Test2::Compare::Negatable;
 
 sub stringify_got { 1 }
 
