@@ -2,7 +2,7 @@ package Test2::Plugin::SRand;
 use strict;
 use warnings;
 
-our $VERSION = '0.000057';
+our $VERSION = '0.000059';
 
 use Carp qw/carp/;
 
@@ -52,7 +52,7 @@ sub import {
         # see. It is nice info and they already asked for noisy output.
 
         test2_add_callback_post_load(sub {
-            test2_stack()->top; # Insure we have at least 1 hub
+            test2_stack()->top; # Ensure we have at least 1 hub.
             my ($hub) = test2_stack()->all;
             $hub->send(
                 Test2::Event::Note->new(
