@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000057';
+our $VERSION = '0.000059';
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -18,6 +18,7 @@ use Test2::Compare qw{
 
 use Test2::Compare::Array();
 use Test2::Compare::Bag();
+use Test2::Compare::Bool();
 use Test2::Compare::Custom();
 use Test2::Compare::Event();
 use Test2::Compare::Hash();
@@ -40,6 +41,7 @@ use Test2::Compare::Wildcard();
     'Test2::Tools::Compare'         => 1,
     'Test2::Compare::Array'         => 1,
     'Test2::Compare::Bag'           => 1,
+    'Test2::Compare::Bool'          => 1,
     'Test2::Compare::Custom'        => 1,
     'Test2::Compare::Event'         => 1,
     'Test2::Compare::Hash'          => 1,
@@ -61,10 +63,10 @@ our @EXPORT = qw/is like/;
 our @EXPORT_OK = qw{
     is like isnt unlike
     match mismatch validator
-    hash array bag object meta meta_check number string subset
+    hash array bag object meta meta_check number string subset bool
     in_set not_in_set check_set
     item field call call_list call_hash prop check all_items all_keys all_vals all_values
-    end filter_items
+    etc end filter_items
     T F D DF DNE FDNE E U
     event fail_events
     exact_ref
@@ -78,7 +80,37 @@ sub is($$;$@) {
     my $delta = compare($got, $exp, \&strict_convert);
 
     if ($delta) {
-        $ctx->ok(0, $name, [$delta->diag, @diag]);
+        # Temporary thing.
+        my $count = 0;
+        my $implicit = 0;
+        my @deltas = ($delta);
+        while (my $d = shift @deltas) {
+            my $add = $d->children;
+            push @deltas => @$add if $add && @$add;
+            next if $d->verified;
+            $count++;
+            $implicit++ if $d->note && $d->note eq 'implicit end';
+        }
+
+        if ($implicit == $count) {
+            $ctx->ok(1, $name);
+            my $meth = $ENV{AUTHOR_TESTING} ? 'throw' : 'alert';
+            my $type = $delta->render_check;
+            $ctx->$meth(
+                join "\n",
+                "!!! NOTICE OF BEHAVIOR CHANGE !!!",
+                "This test uses at least 1 $type check without using end() or etc().",
+                "The old behavior was to default to etc() when inside is().",
+                "The old behavior was a bug.",
+                "The new behavior is to default to end().",
+                "This test will soon start to fail with the following diagnostics:",
+                $delta->diag,
+                "",
+            );
+        }
+        else {
+            $ctx->ok(0, $name, [$delta->diag, @diag]);
+        }
     }
     else {
         $ctx->ok(1, $name);
@@ -273,6 +305,17 @@ sub number($;@) {
     );
 }
 
+sub bool($;@) {
+    my ($bool, @args) = @_;
+    my @caller = caller;
+    return Test2::Compare::Bool->new(
+        file  => $caller[1],
+        lines => [$caller[2]],
+        input => $bool,
+        @args,
+    );
+}
+
 sub string($;@) {
     my ($str, @args) = @_;
     my @caller = caller;
@@ -346,6 +389,18 @@ sub end() {
     $build->set_ending(1);
 }
 
+sub etc() {
+    my $build = get_build() or croak "No current build!";
+
+    croak "'$build' does not support 'ending'"
+        unless $build->can('ending');
+
+    croak "'etc' should only ever be called in void context"
+        if defined wantarray;
+
+    $build->set_ending(0);
+}
+
 my $_call = sub {
     my ($name, $expect, $context, $func_name) = @_;
     my $build = get_build() or croak "No current build!";
@@ -511,9 +566,10 @@ sub event($;$) {
     my $event;
     if (!$spec) {
         $event = Test2::Compare::Event->new(
-            etype => $intype,
-            file  => $caller[1],
-            lines => [$caller[2]],
+            etype  => $intype,
+            file   => $caller[1],
+            lines  => [$caller[2]],
+            ending => 0,
         );
     }
     elsif (!ref $spec) {
@@ -523,6 +579,7 @@ sub event($;$) {
         $event = build('Test2::Compare::Event', $spec);
         $event->set_etype($intype);
         $event->set_builder($spec);
+        $event->set_ending(0) unless defined $event->ending;
     }
     else {
         my $refcheck = Test2::Compare::Hash->new(
@@ -534,7 +591,8 @@ sub event($;$) {
             refcheck => $refcheck,
             file     => $caller[1],
             lines    => [$caller[2]],
-            etype => $intype,
+            etype    => $intype,
+            ending   => 0,
         );
     }
 
@@ -599,10 +657,10 @@ the field.
     use Test2::Tools::Compare qw{
         is like isnt unlike
         match mismatch validator
-        hash array bag object meta number string subset
+        hash array bag object meta number string subset bool
         in_set not_in_set check_set
         item field call call_list call_hash prop check all_items all_keys all_vals all_values
-        end filter_items
+        etc end filter_items
         T F D DNE FDNE E
         event fail_events
         exact_ref
@@ -833,6 +891,22 @@ These will fail:
     is(undef, DF(), 'foo is defined but false');
     is(1, DF(), 'foo is defined but false');
 
+=item $check = E()
+
+This can be used to check that a value exists. This is useful to check that an
+array has more values, or to check that a key exists in a hash, even if the
+value is undefined.
+
+These pass:
+
+    is(['a', 'b', undef], ['a', 'b', E()], "There is a third item in the array");
+    is({a => 1, b => 2}, {a => 1, b => E()}, "The 'b' key exists in the hash");
+
+These will fail:
+
+    is(['a', 'b'], ['a', 'b', E()], "Third item exists");
+    is({a => 1}, {a => 1, b => E()}, "'b' key exists");
+
 =item $check = DNE()
 
 This can be used to check that no value exists. This is useful to check the end
@@ -865,20 +939,45 @@ B<Note: None of these are exported by default. You need to request them.>
 
 Verify that the value matches the given string using the C<eq> operator.
 
+=item $check = !string "..."
+
+Verify that the value does not match the given string using the C<ne> operator.
+
 =item $check = number ...;
 
 Verify that the value matches the given number using the C<==> operator.
 
+=item $check = !number ...;
+
+Verify that the value does not match the given number using the C<!=> operator.
+
+=item $check = bool ...;
+
+Verify the value has the same boolean value as the given argument (XNOR).
+
+=item $check = !bool ...;
+
+Verify the value has a different boolean value from the given argument (XOR).
+
 =item $check = match qr/.../
 
+=item $check = !mismatch qr/.../
+
 Verify that the value matches the regex pattern. This form of pattern check
 will B<NOT> stringify references being checked.
 
+B<Note:> C<!mismatch()> is documented for completion, please do not use it.
+
+=item $check = !match qr/.../
+
 =item $check = mismatch qr/.../
 
 Verify that the value does not match the regex pattern. This form of pattern
 check will B<NOT> stringify references being checked.
 
+B<Note:> C<mismatch()> was created before overloading of C<!> for C<match()>
+was a thing.
+
 =item $check = validator(sub{ ... })
 
 =item $check = validator($NAME => sub{ ... })
@@ -1006,10 +1105,16 @@ Enforce that no keys are found in the hash other than those specified. This is
 essentially the C<use strict> of a hash check. This can be used anywhere in the
 hash builder, though typically it is placed at the end.
 
+=item etc()
+
+Ignore any extra keys found in the hash. This is the opposite of C<end()>.
+This can be used anywhere in the hash builder, though typically it is placed at
+the end.
+
 =item DNE()
 
 This is a handy check that can be used with C<field()> to ensure that a field
-(D)oes (N)not (E)xist.
+(D)oes (N)ot (E)xist.
 
     field foo => DNE();
 
@@ -1095,10 +1200,16 @@ block, and can call it any number of times with any number of arguments.
 Enforce that there are no indexes after the last one specified. This will not
 force checking of skipped indexes.
 
+=item etc()
+
+Ignore any extra items found in the array. This is the opposite of C<end()>.
+This can be used anywhere in the array builder, though typically it is placed
+at the end.
+
 =item DNE()
 
 This is a handy check that can be used with C<item()> to ensure that an index
-(D)oes (N)not (E)xist.
+(D)oes (N)ot (E)xist.
 
     item 5 => DNE();
 
@@ -1139,6 +1250,12 @@ builder sub, and must be called in void context.
 
 Enforce that there are no more items after the last one specified.
 
+=item etc()
+
+Ignore any extra items found in the array. This is the opposite of C<end()>.
+This can be used anywhere in the bag builder, though typically it is placed
+at the end.
+
 =back
 
 =head2 ORDERED SUBSET BUILDER
@@ -1377,6 +1494,12 @@ exist.
 Turn on strict array/hash checking, ensuring that no extra keys/indexes
 are present.
 
+=item etc()
+
+Ignore any extra items found in the hash/array. This is the opposite of
+C<end()>.  This can be used anywhere in the builder, though typically it is
+placed at the end.
+
 =back
 
 =head2 EVENT BUILDERS
@@ -1492,6 +1615,11 @@ Process ID in which the event was generated.
 
 =back
 
+B<NOTE>: Event checks have an implicit C<etc()> added. This means you need to
+use C<end()> if you want to fail on unexpected hash keys or array indexes. This
+implicit C<etc()> extends to all forms, including builder, hashref, and no
+argument.
+
 =item @checks = fail_events $TYPE;
 
 =item @checks = fail_events $TYPE => sub { ... };
